@@ -17,17 +17,34 @@ from beneath.utils import StreamQualifier
 
 class Stream:
     """
-    Represents a data-plane connection to a stream. I.e., this class is used to
-    query, peek, consume and write to a stream. You cannot use this class to do control-plane
-    actions like creating streams or updating their details (use `client.admin.streams` directly).
+    Represents a data-plane connection to a stream.
+    To find or create a stream, see :class:`beneath.Client`.
+
+    Use it to get a StreamInstance, which you can query, replay, subscribe and write to.
+    Learn more about streams and instances at https://about.beneath.dev/docs/concepts/streams/.
     """
 
     client: Client
+
     qualifier: StreamQualifier
+
     admin_data: dict
+
     stream_id: uuid.UUID
+    """
+    The stream ID
+    """
+
     schema: Schema
+    """
+    The stream's schema
+    """
+
     primary_instance: StreamInstance
+    """
+    The current primary stream instance.
+    This is probably the object you will use to write/query the stream.
+    """
 
     # INITIALIZATION
 
@@ -75,25 +92,49 @@ class Stream:
     # MANAGEMENT
 
     async def delete(self):
+        """
+        Deletes the stream and all its instances and data.
+        """
         await self.client.admin.streams.delete(self.stream_id)
 
     # INSTANCES
 
     async def find_instances(self) -> Iterable[StreamInstance]:
+        """
+        Returns a list of all the stream's instances.
+        Learn more about instances at https://about.beneath.dev/docs/concepts/streams/.
+        """
         instances = await self.client.admin.streams.find_instances(self.admin_data["streamID"])
         instances = [StreamInstance(stream=self, admin_data=i) for i in instances]
         return instances
 
-    async def stage_instance(
-        self, version: int, make_primary=None, make_final=None, dry=False
+    async def create_instance(
+        self,
+        version: int,
+        make_primary=None,
+        update_if_exists=None,
+        dry=False,
     ) -> StreamInstance:
+        """
+        Creates and returns a new instance for the stream.
+        Learn more about instances at https://about.beneath.dev/docs/concepts/streams/.
+
+        Args:
+            version (int):
+                The version number to assign to the instance
+            make_primary (bool):
+                Immediately make the new instance the stream's primary instance
+            update_if_exists (bool):
+                If true and an instance for ``version`` already exists, will update and return the
+                existing instance.
+        """
         if dry:
-            return DryStreamInstance(self, version=version, primary=make_primary, final=make_final)
-        instance = await self.client.admin.streams.stage_instance(
+            return DryStreamInstance(self, version=version, primary=make_primary)
+        instance = await self.client.admin.streams.create_instance(
             stream_id=self.admin_data["streamID"],
             version=version,
-            make_final=make_final,
             make_primary=make_primary,
+            update_if_exists=update_if_exists,
         )
         instance = StreamInstance(stream=self, admin_data=instance)
         return instance
